//{{NO_DEPENDENCIES}}
//
// Copyright 2000, International Business Machines Corporation and others.
// All Rights Reserved.
// 
// This software has been released under the terms of the IBM Public
// License.  For details, see the LICENSE file in the top-level source
// directory or online at http://www.openafs.org/dl/license10.html
//
// Used by afs_shl_ext.rc
//
#define IDM_AUTHENTICATION              1
#define IDM_ACL_SET                     2
#define IDM_VOLUME_PROPERTIES           3
#define IDM_VOLUMEPARTITION_UPDATENAMEIDTABLE 4
#define IDM_MOUNTPOINT_SHOW             5
#define IDM_MOUNTPOINT_REMOVE           6
#define IDM_MOUNTPOINT_MAKE             7
#define IDM_FLUSH                       8
#define IDM_FLUSH_VOLUME                9
#define IDM_SHOW_SERVER                 10
#define IDM_SHOWCELL                    11
#define IDM_SERVER_STATUS               12
#define IDM_SYMBOLICLINK_REMOVE         13
#define IDM_SYMBOLICLINK_ADD            14
#define IDM_SUBMOUNTS                   15
#define IDM_ACL_CLEAN                   16
#define ID_GET_TOKENS                   17
#define ID_DISCARD_TOKENS               18
#define IDM_SUBMOUNTS_EDIT              19
#define IDD_KLOG_DIALOG                 102
#define IDR_MENU_FILE                   129
#define IDD_VOLUME_INFO                 130
#define IDD_SET_AFS_ACL                 131
#define IDD_DIALOG_TEST                 132
#define IDD_MAKE_MOUNT_POINT            133
#define IDD_CLEAR_ACL                   134
#define IDD_SUBMTINFO                   135
#define IDD_ADD_ACL                     136
#define IDD_PARTITION_INFO              137
#define IDD_COPY_ACL                    138
#define IDD_MENU_TEST_DLG               140
#define IDD_WHICH_CELL                  141
#define IDD_WHERE_IS                    142
#define IDD_RESULTS                     143
#define IDD_MOUNT_POINTS                145
#define IDD_DOWN_SERVERS                146
#define IDD_SHOWSERVERS                 147
#define IDD_SERVERSTATUS                148
#define IDD_AUTHENTICATION              149
#define IDD_UNLOG_DIALOG                150
#define IDD_ADD_SUBMOUNT                154
#define IDD_SYMBOLICLINK_ADD            155
#define IDM_REMOVE_SYMLINK              156
#define IDC_LIST                        1001
#define IDC_PASSWORD                    1002
#define IDC_OFFLINE_MSG                 1003
#define IDC_MOTD                        1004
#define IDC_NEW_QUOTA                   1005
#define IDC_QUOTA_SPIN                  1006
#define IDC_DIR_NAME                    1007
#define IDC_CELL_NAME                   1008
#define ID_VOLUME_INFO                  1009
#define IDC_NEGATIVE_ENTRIES            1010
#define ID_SET_ACL                      1011
#define IDC_NORMAL_RIGHTS               1012
#define ID_MAKE_MOUNT_POINT             1013
#define IDC_LOCALCELL                   1014
#define IDC_DIALOG                      1015
#define IDC_READ                        1016
#define IDC_SPECIFIEDCELL               1017
#define IDC_WRITE                       1018
#define IDC_VOLUME                      1019
#define IDC_ALL_CELLS                   1020
#define IDC_CB_A                        1021
#define IDC_CELL                        1022
#define IDC_ADD                         1023
#define IDC_RW                          1024
#define IDC_DONTPROBESERVERS            1025
#define IDC_REMOVE                      1026
#define IDC_FAST                        1027
#define IDC_NORMAL                      1028
#define IDC_LOOKUP                      1029
#define IDC_NEGATIVE                    1030
#define IDC_NAME                        1031
#define IDC_DIR                         1032
#define IDC_LOCK                        1033
#define IDC_LOOKUP2                     1034
#define IDC_INSERT                      1035
#define IDC_CHANGE                      1036
#define IDC_CLEAR                       1037
#define IDC_LOCK2                       1038
#define IDC_DELETE                      1039
#define IDC_ADMINISTER                  1040
#define IDC_CB_B                        1041
#define IDC_NEGATIVE_ENTRY              1042
#define IDC_COPY                        1043
#define IDC_ADD_NEGATIVE_ENTRY          1044
#define IDC_CB_C                        1045
#define IDC_PARTITION_INFO              1046
#define IDC_CB_F                        1047
#define IDC_CB_E                        1048
#define IDC_TOTAL_SIZE                  1049
#define IDC_CB_D                        1050
#define IDC_BLOCKS_FREE                 1051
#define IDC_FROM_DIR                    1052
#define IDC_CB_G                        1053
#define IDC_PERCENT_USED                1054
#define IDC_TO_DIR                      1055
#define IDC_CB_H                        1056
#define IDC_BUTTON1                     1057
#define IDC_BROWSE                      1058
#define IDC_ACL_CLEAR                   1059
#define IDC_ACL_LIST_SET_COPY           1060
#define IDC_SHOWSTATUS                  1061
#define IDC_VOL_PART_PROPERTIES         1062
#define IDC_COLUMN_3                    1063
#define IDC_VOL_PART_UPDATE             1064
#define IDC_COLUMN_4                    1065
#define IDC_MOUNT_POINT_SHOW            1066
#define IDC_MOUNT_POINT_REMOVE          1067
#define IDC_MOUNT_POINT_MAKE            1068
#define IDC_FLUSH_FILEDIR               1069
#define IDC_FLUSH_VOLUME                1070
#define IDC_SHOW_FILESERVER             1071
#define IDC_SHOW_CELL                   1072
#define IDC_ADD_NORMAL_ENTRY            1073
#define IDC_RESULTS_LABEL               1074
#define IDC_CLEAN                       1075
#define IDC_TOKEN_LIST                  1076
#define IDC_REGULAR                     1077
#define IDC_STATIC_READ                 1078
#define IDC_STATIC_WRITE                1079
#define IDC_STATIC_EXECUTE              1080
#define IDC_STATIC_CONTROL              1081
#define IDC_STATIC_INSERT               1082
#define IDC_STATIC_DELETE               1083
#define IDC_STATIC_CONTROL2             1084
#define IDC_SHARE_NAME                  1085
#define IDC_PATH_NAME                   1086
#define ID_ACL_CLEAN                    32772
#define ID_ACL_COPY                     32773
#define ID_ACL_LIST                     32774
#define ID_ACL_SET                      32775
#define ID_VOLUME_CHECK                 32776
#define ID_VOLUME_DISKFREE              32777
#define ID_VOLUME_EXAMINE               32778
#define ID_VOLUME_FLUSH                 32779
#define ID_VOLUME_QUOTA_BRIEF           32780
#define ID_VOLUME_QUOTA_FULL            32781
#define ID_VOLUME_QUOTA_SET             32782
#define ID_VOLUME_SET                   32783
#define ID_FLUSH                        32784
#define ID_WHEREIS                      32785
#define ID_SHOWCELL                     32786
#define ID_MOUNTPOINT_SHOW              32787
#define ID_MOUNTPOINT_REMOVE            32788
#define ID_SHOW_SERVER                  32789
#define ID_AUTHENTICATE                 32790
#define ID_SERVER_STATUS                32791
#define ID_VOLUME_PROPERTIES            32792
#define ID_VOLUME_REFRESH               32793
#define ID_VOLUMEPARTITION_UPDATENAMEIDTABLE 32794
#define ID_ACL_COPY_FROM                32795
#define ID_ACL_COPY_TO                  32796
#define ID_MOUNTPOINT_MAKE              32797
#define IDS_FLUSH_FAILED                32798
#define IDS_FLUSH_ERROR                 32799
#define IDS_FLUSH_OK                    32800
#define IDS_CANT_GET_CELL               32801
#define IDS_FLUSH_VOLUME_ERROR          32802
#define IDS_FLUSH_VOLUME_OK             32803
#define IDS_WHERE_IS                    32804
#define IDS_CLEANACL_NOT_SUPPORTED      32805
#define IDS_ACL_IS_FINE                 32806
#define IDS_CLEANACL_INVALID_ARG        32807
#define IDS_ANY_STRING                  32808
#define IDS_CLEANACL_DONE               32809
#define IDS_CLEANACL_ERROR              32810
#define ID_SUBMOUNTS                    32810
#define IDS_GETRIGHTS_ERROR             32811
#define IDS_DFSACL_ERROR                32812
#define IDS_SAVE_ACL_ERROR              32813
#define IDS_SAVE_ACL_EINVAL_ERROR       32814
#define IDS_ACL_READ_ERROR              32815
#define IDS_NO_DFS_COPY_ACL             32816
#define IDS_COPY_ACL_EINVAL_ERROR       32817
#define IDS_COPY_ACL_ERROR              32818
#define IDS_NOT_MOUNT_POINT_ERROR       32819
#define IDS_LIST_MOUNT_POINT_ERROR      32820
#define IDS_MAKE_MP_NOT_AFS_ERROR       32821
#define IDS_MOUNT_POINT_ERROR           32822
#define IDS_ERROR                       32823
#define IDS_DELETED                     32824
#define IDS_SET_QUOTA_ERROR             32825
#define ID_SUBMOUNTS_CREATE             32826
#define ID_SUBMOUNTS_EDIT               32827
#define ID_REMOVE_SYMLINK               32828
#define IDS_CHECK_SERVERS_ERROR         59146
#define IDS_ALL_SERVERS_RUNNING         59147
#define IDS_CHECK_VOLUMES_OK            59150
#define IDS_CHECK_VOLUMES_ERROR         59151
#define IDS_ACL_ENTRY_NAME_IN_USE       59152
#define IDS_REALLY_DEL_MOUNT_POINTS     59153
#define IDS_DIR_DOES_NOT_EXIST_ERROR    59154
#define IDS_CLEANACL_MSG                59155
#define IDS_COPY_ACL_OK                 59156
#define IDS_GET_TOKENS_NO_AFS_SERVICE   59157
#define IDS_GET_TOKENS_UNEXPECTED_ERROR 59158
#define IDS_GET_TOKENS_UNEXPECTED_ERROR2 59159
#define IDS_ENTER_QUOTA                 59160
#define IDS_AUTHENTICATION_ITEM         59161
#define IDS_ACLS_ITEM                   59162
#define IDS_VOL_PART_ITEM               59163
#define IDS_VOL_PART_PROPS_ITEM         59164
#define IDS_VOL_PART_REFRESH_ITEM       59165
#define IDS_MOUNT_POINT_ITEM            59166
#define IDS_MP_SHOW_ITEM                59167
#define IDS_MP_REMOVE_ITEM              59168
#define IDS_MP_MAKE_ITEM                59169
#define IDS_FLUSH_FILE_DIR_ITEM         59170
#define IDS_FLUSH_VOLUME_ITEM           59171
#define IDS_SHOW_FILE_SERVERS_ITEM      59172
#define IDS_SHOW_CELL_ITEM              59173
#define IDS_SHOW_SERVER_STATUS_ITEM     59174
#define IDS_AFS_ITEM                    59175
#define IDS_SUBMOUNTS_ITEM              59176
#define IDS_GET_SUBMT_INFO_ERROR        59177
#define IDS_REALLY_DELETE_SUBMT         59178
#define IDS_SUBMT_SAVE_FAILED           59179
#define IDS_SUBMOUNTS_CREATE_ITEM       59180
#define IDS_SUBMOUNTS_EDIT_ITEM         59181
#define IDS_EDIT_PATH_NAME              59182
#define IDS_SHOW_CELL                   59183
#define IDS_SHOW_CELL_COLUMN            59184
#define IDS_SHOW_FS                     59185
#define IDS_SHOW_FS_COLUMN              59186
#define IDS_REMOVE_MP                   59187
#define IDS_REMOVE_MP_COLUMN            59188
#define IDS_REMOVE_SYMLINK_ITEM         59189
#define IDS_REALLY_REMOVE_SYMLINK       59190
#define IDS_SYMBOLICLINK_ADD            59191
#define IDS_SYMBOLICLINK_EDIT           59192
#define IDS_SYMBOLICLINK_REMOVE         59193
#define IDS_SYMBOLIC_LINK_ITEM          59194
#define ID_SYMBOLICLINK_ADD             59195
#define ID_SYMBOLICLINK_REMOVE          59196
#define IDS_UNABLE_TO_CREATE_SYMBOLIC_LINK 59197
#define IDS_UNABLE_TO_SET_CURRENT_DIRECTORY 59198
#define IDS_CURRENT_DIRECTORY_PATH_TOO_LONG 59199


// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        163
#define _APS_NEXT_COMMAND_VALUE         32829
#define _APS_NEXT_CONTROL_VALUE         1087
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
